---
title: <span class="badge builder"></span> Folder
---
# <span class="badge builder"></span> Folder

## Constructor

```python
Folder()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> folder.Folder
```

### <span class="badge object-method"></span> description

Description of the folder.

```python
def description(description: str) -> typing.Self
```

### <span class="badge object-method"></span> title

Folder title

```python
def title(title: str) -> typing.Self
```

### <span class="badge object-method"></span> uid

Unique folder id. (will be k8s name)

```python
def uid(uid: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Folder](./object-Folder.md)
